@@ -512,7 +512,7 @@ case 'schedule':
 
 case 'transcode':
     $enable = (get($_POST['enable']) == "true" ? true : false);
-    $config['TRANSCODE']=($enable) ? 'True' : 'False';
+    $config['TRANSCODE']=$enable;
     $result = store($config, $SPODCAST_CONFIG);
     if ($result === SUCCESS) {
         $info['status'] = 'SUCCESS';
@@ -597,7 +597,7 @@ foreach (array_keys($feeds) as $url) {
     }
 }
 
-$TRANSCODE_ENABLED=($config['TRANSCODE'] == "True") ? true : false ;
+$TRANSCODE_ENABLED=($config['TRANSCODE'] == "True") ? true : false;
 $LOG_LEVEL=$config['LOG_LEVEL'];
 $UPDATE_ENABLED=$settings['update_enabled'];
 $UPDATE_START=$settings['update_start'];
